/* 
 * CSE142, 99 Winter
 * Homework 5
 * Valentine's Day
 *
 * Author:     Stephanie Couch
 * Student ID: 9822589
 * Section:    AF
 *	
 * CARD PROGRAM
 *
 * Greeting Card Designer (Ultimate version)
 *
 *  The GP142 graphics window shows some buttons and the inside
 *  or outside (cover) of a greeting card.  The Program
 *  can design what the user wants to card to look like by adding 
 *  and moving objects: 
 *    messages, message color and position
 *    shapes,   shape color and position
 *
 *  To place a message or a greeting, you click on an appropriate button, and 
 *  then you can click on the desired position in the card.  
 */

#include "gp142.h"
#include <math.h>
#include <time.h>
	/* <time.h> is here only so that one function can be called
	to seed the random number generator.*/

#define TRUE    		1
#define FALSE   		0

/*
 * The state, or status you are in determines what happens when you click 
 * the card:
 * ADD SHAPE   -- you click the card, and a new object is placed there.
 *                You get into this mode by clicking an ADD button.
 *                After doing an ADD, you are put into SELECTED mode.
 * SELECTED    -- An object is selected. In this mode, the type 
 *                rotation applies to thecurrent object.*/

#define STATUS_ADD_SHAPE       1
#define STATUS_SELECTED        2
#define STATUS_ADD_NEWSHAPE    3
#define STATUS_ADD_MESSAGE     4
#define STATUS_RESELECT_OBJECT 5

/* Configure the appearance of the buttons on the menu bar 
 * by setting the number of pixels of button height and width
 */
#define BUTTON_HEIGHT  	35
#define BUTTON_WIDTH 	100

/*Number of buttons used in the program*/
#define NUM_BUTTONS 	10

/*The color of the button in current use*/
#define SELECTED_COLOR  RED

/* Position of the card in the window */
#define PAGE_LLX	(-GP142_XMAX + BUTTON_WIDTH +60)
#define PAGE_LLY	(-GP142_YMAX + 100)
#define PAGE_WIDTH	(GP142_XMAX - PAGE_LLX - 80)
#define PAGE_HEIGHT (GP142_YMAX - PAGE_LLY - 50)

/* For many of the GP142 functions, a line width of
 * zero means to fill the shape being drawn.
 */
#define FILL 0
#define NOFILL 1

/* Types of objects we support*/
#define OBJECT_NONE    0
#define OBJECT_SHAPE   1
#define OBJECT_MESSAGE 2

/*Amount of shapes availiable*/
#define MAX_SHAPES      7
#define FIRST_SHAPE_NUM 0

/*Amount of messages availiable*/
#define FIRST_MESSAGE_NUM 0 
#define MAX_MESSAGES      7

/*Amount of borders availiable*/
#define MAX_BORDERS      3
#define FIRST_BORDER_NUM 0
#define STYLE1           0
#define STYLE2           1
#define STYLE3           2

/*Amount of Backgrounds availiable*/
#define MAX_BACKGROUNDS  4
#define FIRST_BACK_NUM   0
#define PLAINBACK        0
#define BIGHEART         1
#define STARSBACK        2
#define WATERBACK        3

/* These are the kinds of shapes we support. */
#define SHAPE_HEART     0
#define SHAPE_STAR      1
#define SHAPE_FATSTAR   2
#define SHAPE_FLASHSTAR 3
#define SHAPE_FLOWER    4
#define SHAPE_ARROW     5
#define SHAPE_FISH      6

/*The maximum amount of one type of object for one card*/
#define NUMBER_ALLOWED 10

/* These are the kinds of messages we support*/
#define BEMINE     0
#define SWEETHEART 1
#define ILOVEU     2
#define HAPPYVDAY  3
#define CUTIEPIE   4
#define WALKMYWAY  5
#define GIMMEEKISS 6

/*Possible places for mouse clicks*/
#define CLICK_BUTTON  1  /* You clicked on SOME button*/
#define CLICK_CARD    2  /* You clicked in the card area */
#define CLICK_OUTSIDE 3	 /* You clicked outside the card area, not on a button*/	


/*******************  FUNCTION PROTOTYPES **************************/

/* Drawing functions */
void DrawBlankScreen (void);
void DrawButtons(int last_button);
void DrawBorder (int border_color, int border_type);
void DrawBackground (int background_color, int background_type);
void DrawCard (int background_color, int background_type,
			   int border_color, int border_type, int status, 
			   int object_count, int object_type, int object_num[], 
			   int object_color[], int object_x[], int object_y[],
			   int message_count, int message_num[], 
			   int message_color[], int message_x[], int message_y[]);
void DrawStyle1 (int border_color);
void DrawStyle2 (int border_color);
void DrawStyle3 (int border_color);
void DrawPlainback (int background_color);
void DrawHeartback (int background_color);
void DrawStarback (void);
void DrawWaterback (int background_color);
void DrawShape (int color[], int shape_type[], int bottom_x[], 
				int bottom_y[], int *object_count);
void DrawHeart (int x, int y, int color);
void DrawStar (int x, int y, int color);
void DrawFatstar (int x, int y, int color);
void DrawFlashstar (int x, int y, int color);
void DrawFlower (int x, int y, int color);
void DrawArrow (int x, int y, int color);
void DrawKissyfish (int x, int y, int color);
void DrawMessage (int shape_type[], int color[], int bottom_x[],
				  int bottom_y[], int *message_count);
void DrawBemine (int x, int y, int color);
void DrawSweetheart (int x, int y, int color);
void DrawIloveu (int x, int y, int color);
void DrawHappyvday (int x, int y, int color);
void DrawCutiepie (int x, int y, int color);
void DrawWalkmyway (int x, int y, int color);
void DrawGimmeekiss (int x, int y, int color);
void Opening(void); /*Introduces the program*/

/* Mouse click handling functions */
void HandleMouseClick(int mouse_x, int mouse_y, int *background_color, 
					  int *background_type, int *border_color, 
					  int *border_type, int *status, int *object_count,
					  int *object_type, int object_num[], int object_color[], 
					  int object_x[], int object_y[], int *selected_shape,
					  int *message_count, int message_num[], int message_color[],
					  int message_x[], int message_y[], int *selected_message,
					  int *last_button);
int ClassifyMouseClick(int mouse_x, int mouse_y);
void HandleButton(int x, int y, int *background_color, 
				  int *background_type, int *border_color, 
				  int *border_type, int *status, int object_count, 
				  int object_type, int object_num[],
				  int object_color[], int object_x[], int object_y[], 
				  int *selected_shape, int message_x[], int message_y[],
				  int *message_count, int *selected_message, 
				  int message_color[], int message_num[], int *last_button);

/* Add a shape or message to the card. */
void AddShape(int x, int y, int *status, int *object_count, 
			   int *object_type, int object_num[], int object_color[], 
			   int object_x[], int object_y[], int *selected_shape);

void AddMessage(int mouse_x, int mouse_y, int *status, int *message_count,
				int message_color[], int message_x[], int message_y[],
				int  *selected_message, int message_num[], int *object_type);


/*Allows the object to be moved as long as it's selected*/
void Move_Object(int object_x[], int object_y[], int x, int y, int *selected);

/*Allows user to reselect an object placed earlier and change position or type*/
void Find_Deselected(int x[], int y[], int mouse_x,int mouse_y, int *selected,
						   int *status, int *count);

/*****************************************************************************

     MAIN

*****************************************************************************/

/* main() has two chief purposes: to contain the important variables and 
 *initialize them, and to contain the "event loop," which constantly looks 
 *to see if an event has happened, and then processes the event by calling 
 *an appropriate function. An example of an event is a mouse click.
 */
int main(void)
{
	int  quit = FALSE;              /* becomes TRUE to exit program */
	int  mouse_x, mouse_y;          /* coordinates of a mouse click */
	char key_hit;                   /* which key was hit            */
	
	
	/*variables and their default values*/
	int background_color = YELLOW;
	int background_type  = 0;
	int border_color     = YELLOW;
	int status           = STATUS_ADD_SHAPE;
	int border_type      = 0;
	
	/*variables related to shapes*/
	int selected_shape;				   /* The current shape being modified*/
	int object_count = 0;              /* Number of shapes on page*/
	int object_type  = OBJECT_NONE;    /* Tells whether a shape, message, none*/
	int object_num[NUMBER_ALLOWED];    /* Tells type of shape*/
	int object_color[NUMBER_ALLOWED];  /* Color of the shape*/
	int object_x[NUMBER_ALLOWED];      /* Position of x coordinate shape */
	int object_y[NUMBER_ALLOWED];	   /* Position of y coordinate shape */
	
	/*variables related to messages*/
	int selected_message;			   /* The current message being modified*/
	int message_count = 0;			   /* Number of messages on page*/
	int message_num[NUMBER_ALLOWED];   /* Tells type of message*/
	int message_color[NUMBER_ALLOWED]; /* Color of the message*/
	int message_x[NUMBER_ALLOWED];     /* Position of x coordinate message*/
	int message_y[NUMBER_ALLOWED];     /* Position of y coordinate message*/


	
	int last_button = -1;              /* Tells the last button clicked*/

	int event;                         /*the most recent GP142 event*/
	
	time_t t; /*needed only when initializing a random number generator*/
	

	/*
	 * INITIALIZATIONS
	 */
	srand (time(&t));	    /* Seed the random number generator */
	

	/* GP142 initializations */
	GP142_open();           /* Open and init the GP142 Graphics Window      */
	GP142_show_text(0);     /* Hide the text window                         */
	GP142_logging(LOG_OFF); /* Change to LOG_ON if you want it.             */
	GP142_clear();	        /* This will clear the window & paint it white. */
	Opening();              /* Introduces the program*/
	GP142_animate(ANI_RUN); /* Enable periodic events                       */
	

	
	/*
	 * The main event loop:
	 * --- ---- ----- -----
	 * wait for the next user action, such as a mouse click or keyboard
	 * keypress, or a periodic update event (allowing us to display the
	 * next frame of an animation -- not used directly in this program)
	 * and call the appropriate function to handle it.  Repeat this until 
	 * the user signals "quit".
	 */
	
	while (!quit) {  /*this is the famous "event loop" */
		
		/*start by redrawing everything */
		DrawBlankScreen ();
		DrawCard (background_color, background_type, border_color, 
					border_type, status, object_count, object_type, object_num, 
					object_color, object_x, object_y, message_count,
					message_num, message_color, message_x, message_y);
					
		DrawButtons(last_button);	  /* Show the buttons...*/ 
		
		/*Wait for something to happen */
		
		event = GP142_await_event(&mouse_x, &mouse_y, &key_hit);
		
		/* Something just happened.  Figure out what it was, and react 
		   appropriately. */
		switch (event) {
		case GP142_QUIT:
			quit = TRUE;           /* set flag to terminate loop           */
			break;
			
		case GP142_MOUSE:
			/* A mouse click has occurred. Call the mouse handler to 
			   decide where the click was and react as needed. */

			HandleMouseClick(mouse_x, mouse_y, &background_color, 
							&background_type, &border_color, 
							&border_type, &status, &object_count, 
							&object_type, object_num, object_color, 
							 object_x, object_y, &selected_shape, 
							 &message_count, message_num,
							 message_color, message_x, message_y,
							 &selected_message, &last_button);			
			break;
			
		default:
			
			break;
			
		}  /*end switch */
		
	}  /* end event loop */
	
	
	/*
	 * WRAP-UP
	 */
	GP142_close();         /* clean up and close graphics window   */
	
	return 0;
}  /*end main */

/*****************************************************************************

     FUNCTIONS

*****************************************************************************/
/* 
 * For a blank screen just draw a white rectangle that covers the whole
 * GP142 window.
 */
void DrawBlankScreen (void) {
	int font_size = 14;

	GP142_rectangleXY (WHITE, -GP142_XMAX, -GP142_YMAX,
					GP142_XMAX, GP142_YMAX, FILL);

} /*end DrawBlankScreen*/

/* 
 * Draws the buttons 
 */
void DrawButtons(int last_button)
{
	char b_labels [NUM_BUTTONS][25] = {
		"Background Style",	
			"Background color",
				"Choose Border",
					"Border color",
						"Select Shape",
							"Object color",
								"Add Shape",
									"Add Message",
										"Select Message",
											"Select Object",
	};
	
	int i, text_offset = -GP142_XMAX + 6, font_size = 12;
	int y, label_y;
	
	/* draw rectangles and labels for each button */
	for(i = 0; i < NUM_BUTTONS; i++) {
		y = GP142_YMAX - i * BUTTON_HEIGHT;
		
		GP142_rectangleXY(BLACK, -GP142_XMAX + 4,
			y - 2, -GP142_XMAX + BUTTON_WIDTH,
			y - BUTTON_HEIGHT - 2, 1);
		
		
		label_y = y - BUTTON_HEIGHT/2;
		
		if (i == last_button)
			GP142_printfXY(SELECTED_COLOR, text_offset, 
						label_y, font_size, b_labels[i]);	
		else
			GP142_printfXY(PURPLE, text_offset, label_y, 
							font_size, b_labels[i]);	
	}	
}/*end DrawButtons*/

/*Draws a background by calling the appropriate type of background*/
void DrawBackground (int background_color, int background_type){

	switch((background_type - FIRST_BACK_NUM)% MAX_BACKGROUNDS){
	
	case PLAINBACK:
		DrawPlainback(background_color);
		break;
	case BIGHEART:
		DrawHeartback(background_color);
		break;
	case STARSBACK:
		DrawStarback();
		break;
	case WATERBACK:
		DrawWaterback(background_color);
		break;
	default:
		break;
	}
}/*end DrawBackground*/

/*Draw a basic solid colored background*/
void DrawPlainback(int background_color){

	GP142_rectangleXY (background_color,
		PAGE_LLX, PAGE_LLY,
		PAGE_LLX+ PAGE_WIDTH, PAGE_LLY+ PAGE_HEIGHT,
		FILL);
}/*end DrawPlainback*/

/*Draw a background with a giant heart on it*/
void DrawHeartback(background_color){
	
	GP142_rectangleXY(background_color,  PAGE_LLX,
		PAGE_LLY, PAGE_LLX + PAGE_WIDTH, PAGE_LLY +PAGE_HEIGHT,
		FILL);
	GP142_circleXY   (PINK, -40- PAGE_LLX, 
					  PAGE_LLY +(PAGE_HEIGHT)-100, 80);
	GP142_circleXY	 (PINK,  PAGE_LLX + 110, 
					  PAGE_LLY + (PAGE_HEIGHT)-100, 80);
	GP142_triangleXY (PINK, 25- PAGE_LLX , PAGE_LLY +(PAGE_HEIGHT)-120,
					  PAGE_LLX +45, PAGE_LLY +(PAGE_HEIGHT)-120,
					  PAGE_LLX+195, PAGE_LLY+40, FILL);
}/*end DrawHeartback*/

/*Draw a background with a stary sky*/
void DrawStarback(void){
	int i,
		other;

	GP142_rectangleXY(BLACK,  PAGE_LLX,
		PAGE_LLY, PAGE_LLX + PAGE_WIDTH, 
		PAGE_LLY +PAGE_HEIGHT, FILL);
	  
	for(i=0; i < rand()%12; i++){
		GP142_pixelXY(WHITE, PAGE_LLX+PAGE_WIDTH-50, 
						PAGE_LLY + PAGE_HEIGHT -50);  
		GP142_pixelXY(WHITE, PAGE_LLX+PAGE_WIDTH-40, 
						PAGE_LLY + PAGE_HEIGHT -20);
		GP142_pixelXY(WHITE, PAGE_LLX+PAGE_WIDTH-150, 
						PAGE_LLY + PAGE_HEIGHT -40);
		GP142_pixelXY(WHITE, PAGE_LLX+PAGE_WIDTH-70, 
						PAGE_LLY + PAGE_HEIGHT -30);
		GP142_pixelXY(WHITE, PAGE_LLX+PAGE_WIDTH-100, 
						PAGE_LLY + PAGE_HEIGHT -70);
		GP142_pixelXY(WHITE, PAGE_LLX+PAGE_WIDTH-90, 
						PAGE_LLY + PAGE_HEIGHT -10);
		GP142_pixelXY(WHITE, PAGE_LLX+50, PAGE_LLY + PAGE_HEIGHT -50); 
		GP142_pixelXY(WHITE, PAGE_LLX+150, PAGE_LLY + PAGE_HEIGHT -40);
		GP142_pixelXY(WHITE, PAGE_LLX+70, PAGE_LLY + PAGE_HEIGHT -70); 
		GP142_pixelXY(WHITE, PAGE_LLX+90, PAGE_LLY + PAGE_HEIGHT -10);
		GP142_pixelXY(WHITE, PAGE_LLX+10, PAGE_LLY + PAGE_HEIGHT -60); 
		GP142_pixelXY(WHITE, PAGE_LLX+20, PAGE_LLY + PAGE_HEIGHT -50); 
		GP142_pixelXY(WHITE, PAGE_LLX+110, PAGE_LLY + PAGE_HEIGHT -90);  
	}
  
	for(other=0; other < rand()%8; other++){
		GP142_pixelXY(WHITE, PAGE_LLX+50, PAGE_LLY + PAGE_HEIGHT -50);
		GP142_pixelXY(WHITE, PAGE_LLX+130, PAGE_LLY + PAGE_HEIGHT -30);  
		GP142_pixelXY(WHITE, PAGE_LLX+10, PAGE_LLY + PAGE_HEIGHT -40);
		GP142_pixelXY(WHITE, PAGE_LLX+100, PAGE_LLY + PAGE_HEIGHT -30);  
		GP142_pixelXY(WHITE, PAGE_LLX+150, PAGE_LLY + PAGE_HEIGHT -70);
		GP142_pixelXY(WHITE, PAGE_LLX+PAGE_WIDTH-50, 
						PAGE_LLY + PAGE_HEIGHT -10); 
		GP142_pixelXY(WHITE, PAGE_LLX+PAGE_WIDTH-70,
						PAGE_LLY + PAGE_HEIGHT -50);
		GP142_pixelXY(WHITE, PAGE_LLX+PAGE_WIDTH-150,
						PAGE_LLY + PAGE_HEIGHT -40);  
		GP142_pixelXY(WHITE, PAGE_LLX+PAGE_WIDTH-10,
						PAGE_LLY + PAGE_HEIGHT -70);
		GP142_pixelXY(WHITE, PAGE_LLX+PAGE_WIDTH-100,
						PAGE_LLY + PAGE_HEIGHT -10); 
	}
		GP142_circleXY(YELLOW, PAGE_LLX +225, PAGE_LLY +PAGE_HEIGHT -40, 20);
		GP142_circleXY(BLACK, PAGE_LLX +250, PAGE_LLY +PAGE_HEIGHT-40, 19);
}
/*Draws a watery background*/
void DrawWaterback(int background_color){
	int i;
	
	/*ocean floor*/
	GP142_rectangleXY(BLUE,  PAGE_LLX, PAGE_LLY, 
		PAGE_LLX + PAGE_WIDTH, PAGE_LLY +PAGE_HEIGHT,
		FILL);

	GP142_rectangleXY(BROWN, PAGE_LLX, PAGE_LLY, 
		PAGE_LLX +(PAGE_WIDTH/2), PAGE_LLY + 90, FILL);
	GP142_rectangleXY(BROWN, PAGE_LLX + PAGE_WIDTH/2, PAGE_LLY, 
		PAGE_LLX+PAGE_WIDTH, PAGE_LLY + 50, FILL);
	GP142_ovalXY(BROWN, PAGE_LLX, PAGE_LLY +50, 
		PAGE_LLX +(PAGE_WIDTH/2) -30, PAGE_LLY + 110, FILL);
	GP142_ovalXY(BROWN, PAGE_LLX + (PAGE_WIDTH/2) - 40, PAGE_LLY+20,
		PAGE_LLX+ PAGE_WIDTH/2 + 50, PAGE_LLY +90, FILL);
	GP142_triangleXY(BROWN, PAGE_LLX+PAGE_WIDTH, PAGE_LLY + 50, 
		PAGE_LLX+PAGE_WIDTH, PAGE_LLY + 70, PAGE_LLX + PAGE_WIDTH -50,
		PAGE_LLY + 50, FILL);
	
	/*Starfish*/	
	GP142_circleXY(YELLOW, PAGE_LLX + 130, PAGE_LLY + 60, 4);
	GP142_triangleXY(YELLOW, PAGE_LLX+ 128, PAGE_LLY + 62, PAGE_LLX + 128,
			PAGE_LLY + 58, PAGE_LLX + 108, PAGE_LLY + 60, FILL);
	GP142_triangleXY(YELLOW, PAGE_LLX+ 128, PAGE_LLY + 61, PAGE_LLX + 132,
			PAGE_LLY + 61, PAGE_LLX + 128, PAGE_LLY + 80, FILL);
	GP142_triangleXY(YELLOW, PAGE_LLX+ 128, PAGE_LLY + 62, PAGE_LLX + 128,
			PAGE_LLY + 58, PAGE_LLX + 148, PAGE_LLY + 66, FILL);
	GP142_triangleXY(YELLOW, PAGE_LLX+ 128, PAGE_LLY + 62, PAGE_LLX + 128,
			PAGE_LLY + 58, PAGE_LLX + 145, PAGE_LLY + 53, FILL);
	GP142_triangleXY(YELLOW, PAGE_LLX+ 128, PAGE_LLY + 62, PAGE_LLX + 128,
			PAGE_LLY + 58, PAGE_LLX + 107, PAGE_LLY + 48, FILL);

	/*Starfish*/	
	GP142_circleXY(PINK, PAGE_LLX+PAGE_WIDTH - 60, PAGE_LLY + 30, 4);
	GP142_triangleXY(PINK, PAGE_LLX+PAGE_WIDTH- 58, PAGE_LLY + 32, 
			PAGE_LLX+PAGE_WIDTH - 58, PAGE_LLY + 28, 
			PAGE_LLX+PAGE_WIDTH-38, PAGE_LLY + 30, FILL);
	GP142_triangleXY(PINK, PAGE_LLX + PAGE_WIDTH- 58, PAGE_LLY + 31, 
			PAGE_LLX +PAGE_WIDTH -62, PAGE_LLY + 31, 
			PAGE_LLX+PAGE_WIDTH-58, PAGE_LLY + 50, FILL);
	GP142_triangleXY(PINK, PAGE_LLX+PAGE_WIDTH- 58, PAGE_LLY + 32, 
			PAGE_LLX +PAGE_WIDTH- 58, PAGE_LLY + 28, 
			PAGE_LLX +PAGE_WIDTH- 78, PAGE_LLY + 36, FILL);
	GP142_triangleXY(PINK, PAGE_LLX+PAGE_WIDTH- 58, PAGE_LLY + 32, 
			PAGE_LLX +PAGE_WIDTH- 58, PAGE_LLY + 28, 
			PAGE_LLX +PAGE_WIDTH- 75, PAGE_LLY + 23, FILL);
	GP142_triangleXY(PINK, PAGE_LLX+PAGE_WIDTH- 58, PAGE_LLY + 32, 
			PAGE_LLX +PAGE_WIDTH- 58, PAGE_LLY + 28, 
			PAGE_LLX +PAGE_WIDTH- 37, PAGE_LLY + 18, FILL);

	/*scallop*/
	GP142_ovalXY(WHITE, PAGE_LLX + 57, PAGE_LLY + 76, PAGE_LLX + 88, 
				PAGE_LLY + 100, FILL);
	GP142_triangleXY(WHITE, PAGE_LLX + 60, PAGE_LLY + 74, PAGE_LLX + 60,
				PAGE_LLY + 82, PAGE_LLX + 54, PAGE_LLY + 74, FILL);
	GP142_triangleXY(WHITE, PAGE_LLX + 85, PAGE_LLY + 74, PAGE_LLX + 85,
				PAGE_LLY + 82, PAGE_LLX + 91, PAGE_LLY+74, FILL);
	GP142_rectangleXY(WHITE, PAGE_LLX + 60, PAGE_LLY + 74, 
				 PAGE_LLX + 85, PAGE_LLY + 82, FILL);
	GP142_lineXY(BLACK, PAGE_LLX+ 62, PAGE_LLY + 96, PAGE_LLX + 62,
				PAGE_LLY + 80, FILL);
	GP142_lineXY(BLACK, PAGE_LLX + 70, PAGE_LLY + 98, PAGE_LLX + 70,
				PAGE_LLY + 78, FILL);
	GP142_lineXY(BLACK, PAGE_LLX + 78, PAGE_LLY + 98, PAGE_LLX + 78,
				PAGE_LLY + 78, FILL);
	GP142_lineXY(BLACK, PAGE_LLX + 85, PAGE_LLY + 94, PAGE_LLX + 85,
				PAGE_LLY + 82, FILL);

	/*shining eyes*/
	i = rand()%2*22;	
	GP142_ovalXY(BLACK, PAGE_LLX + 40, PAGE_LLY + 20, PAGE_LLX + 90,
				PAGE_LLY + 45, FILL);
	GP142_circleXY(WHITE+i, PAGE_LLX + 55, PAGE_LLY + 30, 5);
	GP142_circleXY(WHITE+i, PAGE_LLX + 68, PAGE_LLY + 32, 5);
	GP142_circleXY(BLACK+i, PAGE_LLX + 55, PAGE_LLY + 30, 3);
	GP142_circleXY(BLACK+i, PAGE_LLX + 68, PAGE_LLY + 32, 3);
}


/*Draws a border and allows for user selection of other styles of border*/

void DrawBorder(int border_color, int border_type){
	
	switch((border_type - FIRST_BORDER_NUM) % MAX_BORDERS){
	case STYLE1:
			DrawStyle1(border_color);
		break;
	case STYLE2:
			DrawStyle2(border_color);
		break;
	case STYLE3:
			DrawStyle3(border_color);
		break;
	default:
		break;
	}
}/*end DrawBorder*/

/*Draws the first style of border*/
void DrawStyle1(int border_color){
		int i;

		for(i=0; i<8; i++){
			GP142_circleXY (border_color, PAGE_LLX+5+i*47, PAGE_LLY-15, 9);
			GP142_circleXY (border_color, PAGE_LLX+22+i*47, PAGE_LLY-15, 9);
			GP142_triangleXY (border_color, PAGE_LLX-2 +i*47, PAGE_LLY-15,
						PAGE_LLX + 13 +i * 47, PAGE_LLY - 36,
						PAGE_LLX + 28 + i * 47, PAGE_LLY -15, FILL);
		}
		for(i=0; i<8; i++){
			GP142_circleXY (border_color, PAGE_LLX+5+i*47, 
							PAGE_LLY+25+PAGE_HEIGHT, 9);
			GP142_circleXY (border_color, PAGE_LLX + 22 + i*47, 
							PAGE_LLY+25+PAGE_HEIGHT, 9);
			GP142_triangleXY (border_color, PAGE_LLX-2 +i*47, 
						PAGE_LLY +25 +PAGE_HEIGHT, PAGE_LLX +13 +i*47, 
						PAGE_LLY+4 +PAGE_HEIGHT, PAGE_LLX +28+i*47, 
						PAGE_LLY +25+PAGE_HEIGHT, FILL);
		}

		for(i=1; i<8; i++){
			GP142_circleXY (border_color, PAGE_LLX-10, 
							PAGE_LLY+25+PAGE_HEIGHT - i*49, 9);
			GP142_circleXY (border_color, PAGE_LLX - 27, 
							PAGE_LLY+25+PAGE_HEIGHT-i*49, 9);
			GP142_triangleXY (border_color, PAGE_LLX-35, 
						PAGE_LLY +25 +PAGE_HEIGHT-i*49,
						PAGE_LLX -20, PAGE_LLY+4 +PAGE_HEIGHT-i*49,
						PAGE_LLX-3, PAGE_LLY +25+PAGE_HEIGHT-i*49, FILL);
		}
	
		for(i=1; i<8; i++){
			GP142_circleXY (border_color, PAGE_LLX+11+PAGE_WIDTH, 
							PAGE_LLY+25+PAGE_HEIGHT - i*49, 9);
			GP142_circleXY (border_color, PAGE_LLX +27 +PAGE_WIDTH, 
							PAGE_LLY+25+PAGE_HEIGHT-i*49, 9);
			GP142_triangleXY (border_color, PAGE_LLX+34+PAGE_WIDTH, 
						PAGE_LLY +25 +PAGE_HEIGHT-i*49,
						PAGE_LLX +20+PAGE_WIDTH, PAGE_LLY+4 +PAGE_HEIGHT-i*49,
						PAGE_LLX+1+PAGE_WIDTH, PAGE_LLY +25+PAGE_HEIGHT-i*49,
						FILL);
		}
}/*End DrawStyle1*/

/*Draws the second style of border*/
void DrawStyle2(int border_color){
		int i;

		for(i=0; i<10; i++){
			GP142_triangleXY(border_color, PAGE_LLX +i*40, PAGE_LLY - 10, 
				PAGE_LLX - 20 + i*40, PAGE_LLY - 40, PAGE_LLX +20 +i*40,
				PAGE_LLY - 40, FILL);
		}
		for(i=0; i<10; i++){
			GP142_triangleXY(border_color,PAGE_LLX+i*40,
				PAGE_LLY+10+PAGE_HEIGHT, 
				PAGE_LLX-20+i*40, PAGE_LLY+40+PAGE_HEIGHT, 
				PAGE_LLX+20+i*40,
				PAGE_LLY +40 + PAGE_HEIGHT, FILL);
		}
		for(i=0; i<10; i++){
			GP142_triangleXY(border_color, PAGE_LLX-10, PAGE_LLY+ i*40, 
				PAGE_LLX - 40, PAGE_LLY + 20+ i*40, PAGE_LLX-40 ,
				PAGE_LLY -20+i*40, FILL);
		}
		for(i=0; i<10; i++){
			GP142_triangleXY(border_color, PAGE_LLX+10 + PAGE_WIDTH, 
				PAGE_LLY+ i*40, 
				PAGE_LLX + 40 +PAGE_WIDTH, PAGE_LLY + 20+ i*40, 
				PAGE_LLX+40 +PAGE_WIDTH, PAGE_LLY -20+i*40, FILL);
		}
}/*end DrawStyle2*/

/*Draws the third style of border*/
void DrawStyle3(int border_color){
		int i,
			radius = rand()%5 +8;

		for(i=0; i<10; i++){
			GP142_circleXY(border_color, PAGE_LLX+i*40, PAGE_LLY-19,radius);
		}
		for(i=0; i<10; i++){
			GP142_circleXY(border_color, PAGE_LLX + i * 40,
							PAGE_LLY + 19 + PAGE_HEIGHT, radius);
		}
		for(i=0; i<8; i++){
			GP142_circleXY(border_color, PAGE_LLX - 15, 
							PAGE_LLY + 10 + i * 45, radius);
		}
		for(i=0; i<8; i++){
			GP142_circleXY(border_color, PAGE_LLX+15+PAGE_WIDTH, 
							PAGE_LLY+10+i*45, radius);
		}
}/*end DrawStyle3*/

/*
 * Render (draw) the page and all its contents.
 */
void DrawCard (int background_color, int background_type,int border_color,
			   int border_type,int status, int object_count, 
			   int object_type, int object_num[], 
			   int object_color[], int object_x[], int object_y[],
			   int message_count, int message_num[], int message_color[], 
			   int message_x[], int message_y[])
{
	int font_size=14;
	int i;
	/*
	 * Draw the background of the card.
	 */
	DrawBackground(background_color, background_type);
	DrawBorder(border_color, border_type);
	
	/*Print Name and Student ID in the window*/
	GP142_printfXY(BLACK, -GP142_XMAX+10, -GP142_YMAX + 40, 10, 
					"Stephanie Ann Couch");
	GP142_printfXY(BLACK, -GP142_XMAX+30, -GP142_YMAX + 20, 10, 
					"#9822589");
	
	/* Draw a shape on the card, if one currently exists.*/
	 for(i = 0; i < object_count; i++)
		DrawShape (object_num, object_color, object_x, object_y, &i);
		
	/*Draw a message on the card, if one currently exists.*/
	for(i = 0; i < message_count; i++)
		DrawMessage (message_num, message_color, message_x, message_y, &i);
	
	/*
	 * Write an appropriate status message below the background
	 */
	switch (status) {
	case STATUS_ADD_SHAPE:
		GP142_printfXY (BLACK, PAGE_LLX, PAGE_LLY-60, font_size,
			"Click on the card to add a shape");
		break;
	case STATUS_SELECTED:
		GP142_printfXY (RED, PAGE_LLX, PAGE_LLY-60, font_size-3,
			"Object selected. Click the card to move or click button to change type or color.");
		break;
	case STATUS_ADD_NEWSHAPE:
		GP142_printfXY(BLACK, PAGE_LLX, PAGE_LLY-60, font_size, 
			"Click on the card to add another shape");
		break;
	case STATUS_ADD_MESSAGE:
		GP142_printfXY(BROWN, PAGE_LLX, PAGE_LLY-60, font_size,
			"Click on the card to add a message");
		break;
	case STATUS_RESELECT_OBJECT:
		GP142_printfXY(BLUE, PAGE_LLX, PAGE_LLY-60, font_size, 
			"Click on a shape to reselect it. (Click close to the origin)");
		break;
	default:
		GP142_printfXY (BLACK, PAGE_LLX, PAGE_LLY-60, font_size,
			"Status error -- notify programmer");
		break;
	} /*end switch */
	
	
	 /*end DrawPage */
}

/*
 * Draw one shape.
 */
void DrawShape(int shape_type[], int color[], int bottom_x[], 
			   int bottom_y[], int *object_count) {
	
	if(*object_count<NUMBER_ALLOWED){
		/*Finds type of object selected and displays it on the screen*/
		switch ((shape_type[*object_count] - FIRST_SHAPE_NUM) % MAX_SHAPES){
		
		case SHAPE_HEART:
			DrawHeart (bottom_x[*object_count], bottom_y[*object_count], 
						color[*object_count]);
			break;
		case SHAPE_STAR:
			DrawStar (bottom_x[*object_count], bottom_y[*object_count],
						color[*object_count]);
			break;
		case SHAPE_FATSTAR:
			DrawFatstar (bottom_x[*object_count], bottom_y[*object_count], 
						color[*object_count]);
			break;
		case SHAPE_FLASHSTAR:
			DrawFlashstar (bottom_x[*object_count], bottom_y[*object_count], 
						color[*object_count]);
			break;
		case SHAPE_FLOWER:
			DrawFlower (bottom_x[*object_count], bottom_y[*object_count],
						color[*object_count]);
			break;
		case SHAPE_ARROW:
			DrawArrow (bottom_x[*object_count], bottom_y[*object_count], 
						color[*object_count]);
			break;
		case SHAPE_FISH:
			DrawKissyfish(bottom_x[*object_count], bottom_y[*object_count], 
						color[*object_count]);
			break;
		default:
		/* Unknown shape selected */
			break;
		}
	} /*end switch*/

}/*end DrawShape*/


/*
 * Draw a heart on the card.
 */
#define HEART_WIDTH 35
void DrawHeart (int x, int y, int color) {

	int h = (HEART_WIDTH/2) + (rand () %4);

	GP142_circleXY (color, x - h + 5, y, h);
	GP142_circleXY (color, x + h - 5, y, h);
	GP142_triangleXY (color, x- h*2 +5, y-5,
						x + h*2 -5, y-5,
						x, y - h*2 -5, FILL);

}/*end DrawHeart*/


/*
 * Draw a star on the card.
 */
#define STARPOINTS 5
#define STARRADIUS 40
#define PI 3.1416
void DrawStar (int x, int y, int color) {

	int sp;
	double angle;
	int x1, y1;
	
	color = rand () %9;
	sp = STARPOINTS + (rand () %3);
	for (angle = 0.0; angle < 2 * PI; angle = angle + (2*PI)/sp) {
		x1 = (int) (cos (angle) * STARRADIUS);
		y1 = (int) (sin (angle) * STARRADIUS);
		GP142_lineXY (color, x+x1, y+y1, x-x1, y-y1, 1);

	}
}/*end DrawStar*/

/*Adds a filled in star to the types of shapes that can be selected*/
#define FATSTAR_WIDTH 30
void DrawFatstar (int x, int y, int color)  {

		int h = (FATSTAR_WIDTH) + (rand () %3);
		
	GP142_triangleXY (color, x+ h +5, y- h -4,
						x - h - 5, y- h -4,
						x, y + h - 8, FILL);
	GP142_triangleXY (color, x- h - 5, y + 4,
						x + h + 5, y +4,
						x, y - h - 22, FILL);
}/*end DrawFatstar*/



/*Adds a filled in star that flashes colors to the types of shapes*/
void DrawFlashstar (int x, int y, int color)  {

	color = RED + rand () %6;
		
	GP142_triangleXY (color, x+35, y-34,
						x - 34, y - 34,
						x, y + 22, FILL);
	GP142_triangleXY (color, x - 35, y + 4,
						x + 35, y +4,
						x, y - 52, FILL);
}/*end DrawFlashstar*/

/*Adds a flower to the types of shapes that can be selected*/
#define PETAL_RADIUS 15
#define MIDDLE_RADIUS 5
#define STEM_THICKNESS 3
void DrawFlower (int x, int y, int color) {

	GP142_circleXY(YELLOW, x, y, MIDDLE_RADIUS);
	GP142_lineXY(GREEN, x-2, y-54, x, y-4, STEM_THICKNESS);
	GP142_triangleXY(GREEN, x-2, y-35, x+8, y-27, x-2, y-45, FILL);
	GP142_triangleXY(GREEN, x-2, y-43, x-8, y-34, x-2, y-53, FILL);
	GP142_circleXY(color, x+12, y+12, PETAL_RADIUS);
	GP142_circleXY(color, x-12, y-12, PETAL_RADIUS);
	GP142_circleXY(color, x-12, y+12, PETAL_RADIUS);
	GP142_circleXY(color, x+12, y-12, PETAL_RADIUS);

}/*end DrawFlower*/

/*Adds a flying arrow to the types of shapes that can be selected*/
#define ARROW_WIDTH 3
#define FEATHER_WIDTH 1
#define WIND_EFFECT1 5
#define WIND_EFFECT2 4
void DrawArrow (int x, int y, int color) {

		int h = (WIND_EFFECT1) + (rand () %3);
		int s = (WIND_EFFECT2) + (rand () %3);
	
	GP142_lineXY(color, x-30, y-30, x+30, y+30, ARROW_WIDTH);
	GP142_lineXY(color, x-45-s, y-21-h, x-20-s, y-17-h, FEATHER_WIDTH);
	GP142_lineXY(color, x-47-s, y-27-h, x-22-h, y-22-h, FEATHER_WIDTH);
	GP142_lineXY(color, x-16-s, y-16-h, x-12-s, y-43-h, FEATHER_WIDTH);
	GP142_lineXY(color, x-21-s, y-22-h, x-15-h, y-50-h, FEATHER_WIDTH);
	GP142_triangleXY(color, x+30+h, y+30+h, x+30+h, y+10+h, 
					x+10+h, y+30+h, FILL);
	GP142_circleXY(color, x+25+h, y+14+h, 6);
	GP142_circleXY(color, x+15+h, y+24+h, 6);
}/*end DrawArrow*/

/*Adds two fish who swim to each other and kiss to the shape types*/
void DrawKissyfish (int x, int y, int color) {
	
	int i = rand()%8;
	int s = rand()%3;
	int j = rand()%16;

	/*Fish 1*/
	GP142_ovalXY(color, x+j, y, x-45+j, y+30, FILL);
	GP142_ovalXY(WHITE, x-5+s+j, y+22-s, x-10-s+j, y+15+s, FILL);
	GP142_circleXY(BLACK, x-7+j, y+19, 2);
	GP142_ovalXY(16, x-9+j, y+12, x+1+j, y+8, FILL);
	GP142_triangleXY(color, x-35+j, y+15, x-60+i+j, y+i, 
						x-60+i+j, y+30+i, FILL);
	/*Fish 2*/
	GP142_ovalXY(color, x+30-j, y, x+75-j, y+30, FILL);
	GP142_ovalXY(WHITE, x+35+s-j, y+22-s, x+40-s-j, y+15+s, FILL);
	GP142_circleXY(BLUE, x+37-j, y+19, 2);
	GP142_ovalXY(WHITE, x+39-j, y+12, x+29-j, y+8, FILL);
	GP142_triangleXY(color, x+65-j, y+15, x+90+ i-j, y+i, 
						x+90+i-j, y+30+i, FILL);
	/*bubbles*/
	GP142_circleXY(WHITE, x+10, y+25+i*3, 5);
	GP142_ovalXY(BLUE, x+10, y+21+i*3, x+6, y+28+i*3, NOFILL );
	GP142_circleXY(WHITE, x+20, y+45+i*3, 5);
	GP142_ovalXY(BLUE, x+20, y+41+i*3, x+16, y+50+i*3, NOFILL );

}/*end DrawKissyfish*/

/*Displays a message*/
void DrawMessage(int shape_type[], int color[], int bottom_x[], 
				 int bottom_y[], int *message_count) {
	
	if(*message_count<NUMBER_ALLOWED){

		/*Statement allows the correct type of message to be displayed*/
		switch((shape_type[*message_count]-FIRST_MESSAGE_NUM)%MAX_MESSAGES){
		case BEMINE:
			DrawBemine (bottom_x[*message_count], bottom_y[*message_count],
						color[*message_count]);
			break;
		case SWEETHEART:
			DrawSweetheart (bottom_x[*message_count], bottom_y[*message_count],
						color[*message_count]);
			break;
		case ILOVEU:
			DrawIloveu (bottom_x[*message_count], bottom_y[*message_count], 
						color[*message_count]);
			break;
		case HAPPYVDAY:
			DrawHappyvday (bottom_x[*message_count], bottom_y[*message_count], 
						color[*message_count]);
			break;
		case CUTIEPIE:
			DrawCutiepie (bottom_x[*message_count], bottom_y[*message_count],
						color[*message_count]);
			break;
		case WALKMYWAY:
			DrawWalkmyway (bottom_x[*message_count], bottom_y[*message_count], 
						color[*message_count]);
			break;
		case GIMMEEKISS:
			DrawGimmeekiss (bottom_x[*message_count], bottom_y[*message_count], 
						color[*message_count]);
			break;
		default:
		/* Unknown message selected */
			break;
		}
	} /*end switch*/

}/*end DrawMessage*/

/*Adds message of "Be My Valentine" to the types of messages*/
void DrawBemine (int x, int y, int color){
	int font_size = 17;
	
	GP142_printfXY(color, x, y, font_size, 
		"Be My Valentine");

}/*end DrawBemind*/

/*Adds message of "Sweetheart" to the types of messages*/
void DrawSweetheart (int x, int y, int color){
	int	font_size= rand()%4 + 16;
	
	GP142_printfXY(color, x, y, font_size,
		"SWEETHEART");

}/*end DrawSweetheart*/

/*Adds message of "I Love You" to the types of messages*/
void DrawIloveu (int x, int y, int color){
	int font_size = 18,
		i=rand() % 5;

	GP142_printfXY(color, x, y, font_size,
		"I ");
	GP142_printfXY(color, x+15, y, font_size+i,
		"Love");
	GP142_printfXY(color, x+55, y, font_size,
		" You!");

}/*end DrawIloveu*/

/*Adds message of "Happy Valentine's Day" to the types of messages*/
void DrawHappyvday (int x, int y, int color){
	int font_size = 16;

	color = rand() % 10;
	
	GP142_printfXY(color, x, y, font_size,
		"Happy Valentine's Day!");

}/*end DrawHappyvday*/

/*Adds message of "Cutie Pi" to the types of messages*/
void DrawCutiepie (int x, int y, int color){
	int font_size = 18;
	
	GP142_printfXY(color, x, y, font_size,
		"Cutie Pi");	

}/*end DrawCutiepie*/

/*Adds message of "Walk My Way Baby!" to the types of messages*/
void DrawWalkmyway (int x, int y, int color){
	int font_size = 16;
	
	GP142_printfXY(color, x + 3*(rand()%4), y, font_size,
		"Walk My Way Baby!");

}/*end DrawWalkmyway*/

/*Adds message of "Gimmee A Kiss!" to the types of messages*/
void DrawGimmeekiss (int x, int y, int color){
	int font_size = 18,
		i = rand()%4;

	GP142_printfXY(color, x, y, font_size, 
					"Gimmee A ");
	GP142_printfXY(color, x+86, y, font_size + i,
					"K");
	GP142_printfXY(color, x+115, y, font_size + i,
					"S");
	font_size = 20;
	GP142_printfXY(color, x+98, y , font_size + i,
					"I");
	GP142_printfXY(color, x+105, y, font_size + i,
					"S");

}/*end DrawGimmeekiss*/


/*
 * Mouse clicks occur in one of three regions of interest: 
 * on buttons, on the card, or anywhere else. This function 
 * returns the where the card was clicked.
 */
int  ClassifyMouseClick(int mouse_x, int mouse_y)
{
  if ((mouse_x < -GP142_XMAX + BUTTON_WIDTH) &&
      (mouse_y < GP142_YMAX) &&
      (mouse_y > (GP142_YMAX - NUM_BUTTONS*BUTTON_HEIGHT)))
  
	return CLICK_BUTTON;
  
  else if (mouse_x >= PAGE_LLX && mouse_x < PAGE_LLX + PAGE_WIDTH
	  && mouse_y >= PAGE_LLY && mouse_y < PAGE_LLY + PAGE_HEIGHT)
	return CLICK_CARD;
  else
    return CLICK_OUTSIDE;

}/*end ClassifyMouseClick*/


/*
 * Decide where a mouse click occured, and react appropriately.
 */
void HandleMouseClick(int mouse_x, int mouse_y, int *background_color, 
					  int *background_type, int *border_color, 
					  int *border_type, int *status, int *object_count,
					  int *object_type, int object_num[], 
					  int object_color[], int object_x[], int object_y[],
					  int *selected_shape, int *message_count, 
					  int message_num[], int message_color[],
					  int message_x[], int message_y[], int *selected_message,
					  int *last_button)
{

	int mouse_click;
	mouse_click = ClassifyMouseClick(mouse_x, mouse_y);
			
	if (mouse_click == CLICK_BUTTON) {
				
		/* A button has been clicked.  Call a function to handle it*/
		/* most of the variables passed as args will NOT change*/
		HandleButton(mouse_x, mouse_y, background_color, background_type,
					 border_color,border_type, status, 
					 *object_count, *object_type, object_num, 
					 object_color, object_x, object_y, selected_shape,
					 message_x, message_y, message_count, selected_message,
					 message_color, message_num, last_button);

	} else if (mouse_click == CLICK_CARD) {
		/* Add a shape, if there isn't one already */
		if (*status == STATUS_ADD_NEWSHAPE || *status == STATUS_ADD_SHAPE)
		{
			AddShape(mouse_x, mouse_y, status, object_count, 
			   object_type, object_num, object_color, 
			   object_x, object_y, selected_shape);
		}
		/*Allows the object to be moved around*/
		else if(*status == STATUS_SELECTED)
		{	
			if(*object_type == OBJECT_SHAPE)
				Move_Object(object_x, object_y, mouse_x, mouse_y,
					selected_shape);
			else if (*object_type == OBJECT_MESSAGE)
				Move_Object(message_x, message_y, mouse_x, mouse_y,
					selected_message);
		}
		/*Allows a message to be added*/
		else if(*status == STATUS_ADD_MESSAGE)
		{
			AddMessage(mouse_x, mouse_y, status, message_count, 
				message_color, message_x, message_y, selected_message,
				message_num, object_type);
		}
		/*Allows an object to be reselected and changed*/
		else if(*status == STATUS_RESELECT_OBJECT)
		{
			if (*object_type == OBJECT_SHAPE)
			Find_Deselected(object_x, object_y, mouse_x, 
				mouse_y, selected_shape, status, object_count);
			if (*object_type == OBJECT_MESSAGE)
			Find_Deselected(message_x, message_y, mouse_x, 
				mouse_y, selected_message, status, message_count);
		}
	/* Ignore any other mouse clicks */
	}
}/*end HandleMouseClick*/

/* 
 * Figure out which button was clicked, if any, and do the right 
 * thing.
 */
void HandleButton(int x, int y, int *background_color, int *background_type,
				  int *border_color, int *border_type, int *status, 
				  int object_count, int object_type, int object_num[],
				  int object_color[], int object_x[], int object_y[], 
				  int *selected_shape, int message_x[], int message_y[],
				  int *message_count, int *selected_message, 
				  int message_color[], int message_num[], int *last_button)

{
	int buttonNum = 0;

	/* If we're outside of this area, we could not have clicked on
	* a button.
	*/
	if (x > -GP142_XMAX + BUTTON_WIDTH)  
		return ;	/*That's an error situation*/
	
					/* We know the mouse clicked in the column
					 * of buttons. Calculate which one.
					 */
	buttonNum = (GP142_YMAX - y)/BUTTON_HEIGHT;	 

	
		switch(buttonNum) {
		case 0:
			/*Change background style*/
			*background_type = (*background_type+1) % MAX_BACKGROUNDS;
			*last_button = 0;
			break;
		case 1:
			/* Change the background color */
			*background_color = (*background_color + 1) % MAX_COLORS;
			*last_button = 1;
			break;
		case 2:
			/*Change the background type*/
			*border_type = (*border_type +1)%MAX_SHAPES;
			*last_button = 2;
			break;
		case 3:
			/*Change the border color*/
			*border_color = (*border_color +1) % MAX_COLORS;
			*last_button = 3;
			break;
		case 4:
			/* Change the type of the currently selected object */
			if (object_type == OBJECT_SHAPE){
				object_num[*selected_shape]=
						(object_num[*selected_shape]+1)%MAX_SHAPES;
			}
			*last_button =4;
			break;
		case 5:
			/*Change the color of the selected object*/
			if (object_type == OBJECT_SHAPE)
			object_color[*selected_shape]=(object_color[*selected_shape]+1)
											% MAX_COLORS;
			else if (object_type == OBJECT_MESSAGE)
			message_color[*selected_message]=
					(message_color[*selected_message]+1)% MAX_COLORS;
			*last_button = 5;
			break;
		case 6:
			/*Add another object to the card*/
			
			*status = STATUS_ADD_NEWSHAPE;
			*last_button = 6;
			break;
		case 7:
			/*Add message*/
			*status = STATUS_ADD_MESSAGE;
			*last_button = 7;
			break;
		case 8:
			/*Change the type of the currently selected message*/
			if (object_type == OBJECT_MESSAGE)
				message_num[*selected_message]=
					(message_num[*selected_message]+1)%MAX_COLORS;
			*last_button = 8;
			break;
		case 9:
			/*Reselect a deselected object*/
			*status = STATUS_RESELECT_OBJECT;
			*last_button = 9;
			break;
		default:
			*status = 999;
			/*Bad news if this is ever reached! */
			break;
		}
	
}/*end HandleButton*/


/* If there's room for another shape, add it to the card. */
void AddShape(int x, int y, int *status, int *object_count, 
			   int *object_type, int object_num[], int object_color[],
			   int object_x[], int object_y[], int *selected_shape)
{		
	if (*object_count < NUMBER_ALLOWED) {
		object_color[*object_count] = RED;
		*object_type = OBJECT_SHAPE;
		object_num[*object_count] = SHAPE_HEART;
		object_x[*object_count] = x;
		object_y[*object_count] = y;
		*status = STATUS_SELECTED;
		*selected_shape = *object_count;
		*object_count = *object_count + 1;
	}

}/*end AddShape*/

/*If there's room for another shape, add it to the card.*/
void AddMessage(int mouse_x, int mouse_y, int *status, 
				int *message_count, int message_color[],
				int message_x[], int message_y[], 
				int  *selected_message, int message_num[], 
				int *object_type){

	if(*message_count < NUMBER_ALLOWED) {
		message_color[*message_count] = GREEN;
		*object_type = OBJECT_MESSAGE;
		message_num[*message_count] = BEMINE;
		message_x[*message_count] = mouse_x;
		message_y[*message_count] = mouse_y;
		*status = STATUS_SELECTED;
		*selected_message = *message_count;
		*message_count = *message_count +1;
	}
}/*end AddMessage*/

/*Allow the user to move the selected shape anywhere on the card*/
void Move_Object(int object_x[], int object_y[], int x, int y, 
				 int *selected){
	
	object_x[*selected] = x;
	object_y[*selected] = y;

}/*end Move_Object*/

/*Allow the user to reselect an object and change it's type, color, 
/*or move it*/
void Find_Deselected(int x[], int y[], int mouse_x,int mouse_y, 
						   int *selected, int *status, int *count){

		int i;

		for(i=0; i<*count; i++){
			if((x[i]-mouse_x<5 && x[i] - mouse_x>-5) &&
				(y[i]-mouse_y<5 && y[i]-mouse_y)){
					*selected = i;
					*status = STATUS_SELECTED;
			}
			
		}
}/*end Find_Deselected*/

void Opening(void){   	
	int mouse_x;	
	int mouse_y;
	char key_hit;
		
	GP142_rectangleXY(PURPLE, -GP142_XMAX, -GP142_YMAX, GP142_XMAX, 
		              GP142_YMAX, FILL);
	GP142_printfXY(YELLOW, -GP142_XMAX + 90, GP142_YMAX - 100, 
		           21, "STEPHANIE COUCH'S CSE 142 PRODUCTIONS");
	

	DrawFlower(-GP142_XMAX +80, GP142_YMAX-200, RED);
	DrawFlower(GP142_XMAX -80, GP142_YMAX-200, RED);
	GP142_printfXY(RED, -GP142_XMAX + 140, GP142_YMAX -250,
		           45, "Valentine Insanity");
	GP142_printfXY(RED, -GP142_XMAX + 180, GP142_YMAX -300,
		           45, "Card Creator");

    
    GP142_printfXY(GREEN, -GP142_XMAX +160, -GP142_YMAX + 100,
		           10,"Click the screen or press a key to start creating!");
      
	GP142_await_event(&mouse_x, &mouse_y, &key_hit);

}/*end Opening*/